==> icaatom-1.0.5.tgz: icaatom-1.0.5/apps/qubit/modules/digitalobject/actions/listAction.class.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @package    qubit
 * @subpackage digitalobject
 * @author     David Juhasz <david@artefactual.com>
 * @version    svn: $id
 */
class DigitalObjectListAction extends sfAction
{
  /**
   * Execute digitalobject list action
   *
   * @param sfWebRequest $request
   */
  public function execute($request)
  {
    $this->culture = $this->getUser()->getCulture();
    
    if ($this->getRequestParameter('sort'))
    {
      $this->sort = $this->getRequestParameter('sort');
    }
    else
    {
      //default sort column for list view
      $this->sort = 'nameUp';
    }

    // TODO Figure out how to replace this with an ORM resultset
    // Build funky join query to get a count of top level digital objects
    // for each media type (term)
    $criteria = new Criteria;
    $criteria->add(QubitTerm::TAXONOMY_ID, QubitTaxonomy::MEDIA_TYPE_ID);
    $criteria->addJoin(QubitTerm::ID, QubitDigitalObject::MEDIA_TYPE_ID, Criteria::LEFT_JOIN);
    $criteria->addAsColumn('hits', 'COUNT('.QubitDigitalObject::ID.')');
    $criteria->addGroupByColumn(QubitTerm::ID);
    
    /*
    $criteria = new Criteria;
    $criteria->addSelectColumn(QubitTerm::ID);
    $criteria->addSelectColumn('COUNT('.QubitDigitalObject::ID.')');
    $criteria->addJoin(QubitTerm::ID, QubitDigitalObject::MEDIA_TYPE_ID, Criteria::LEFT_JOIN);
    $criteria->addJoin(QubitTerm::ID, QubitTermI18n::ID);
    $criteria->add(QubitDigitalObject::PARENT_ID, null, Criteria::ISNULL);
    $criteria->add(QubitTerm::TAXONOMY_ID, QubitTaxonomy::MEDIA_TYPE_ID);
    $criteria->addGroupByColumn(QubitTerm::ID);
    */

    // Sort the list
    switch ($this->sort)
    {
      case 'nameUp':
        $criteria->addAscendingOrderByColumn('name'); break;
      case 'nameDown':
        $criteria->addDescendingOrderByColumn('name'); break;
      case 'hitsUp':
        $criteria->addAscendingOrderByColumn('hits'); break;
      case 'hitsDown':
        $criteria->addDescendingOrderByColumn('hits'); break;
    }
    
    // Add I18n fallback
    $options = array();
    $criteria = QubitCultureFallback::addFallbackCriteria($criteria, 'QubitTerm', $this->culture, $options);
    
    $this->terms = QubitTerm::get($criteria);

    //determine if user has edit priviliges
    $this->editCredentials = false;
    if (SecurityPriviliges::editCredentials($this->getUser(), 'actor'))
    {
      $this->editCredentials = true;
    }

    //set view template
    switch ($this->getRequestParameter('template'))
    {
      case 'anotherTemplate' :
        $this->setTemplate('anotherTemplate');
        break;
      default :
        //$this->setTemplate(sfConfig::get('app_default_template_mediatype_list'));
        $this->setTemplate('list');
    }
  }
}

==> icaatom-1.0.6.tgz: icaatom-1.0.6/apps/qubit/modules/digitalobject/actions/listAction.class.php <==
<?php

/*
 * This file is part of Qubit Toolkit.
 *
 * Qubit Toolkit is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 2 of the License, or
 * (at your option) any later version.
 *
 * Qubit Toolkit is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Qubit Toolkit.  If not, see <http://www.gnu.org/licenses/>.
 */

/**
 * @package    qubit
 * @subpackage digitalobject
 * @author     David Juhasz <david@artefactual.com>
 * @version    svn: $Id: listAction.class.php 2409 2009-04-25 03:10:19Z jablko $
 */
class DigitalObjectListAction extends sfAction
{
  /**
   * Execute digitalobject list action
   *
   * @param sfWebRequest $request
   */
  public function execute($request)
  {
    if ($this->getRequestParameter('sort'))
    {
      $this->sort = $this->getRequestParameter('sort');
    }
    else
    {
      //default sort column for list view
      $this->sort = 'nameUp';
    }

    // Build funky join query to get a count of top level digital objects
    // for each media type (term)
    $criteria = new Criteria;
    $criteria->add(QubitTerm::TAXONOMY_ID, QubitTaxonomy::MEDIA_TYPE_ID);
    $criteria->addJoin(QubitTerm::ID, QubitDigitalObject::MEDIA_TYPE_ID, Criteria::LEFT_JOIN);
    $criteria->addAsColumn('hits', 'COUNT('.QubitDigitalObject::ID.')');
    $criteria->addGroupByColumn(QubitTerm::ID);

    // Sort the list
    switch ($this->sort)
    {
      case 'nameUp':
        $criteria->addAscendingOrderByColumn('name');
        break;
      case 'nameDown':
        $criteria->addDescendingOrderByColumn('name');
        break;
      case 'hitsUp':
        $criteria->addAscendingOrderByColumn('hits');
        break;
      case 'hitsDown':
        $criteria->addDescendingOrderByColumn('hits');
        break;
    }

    // Add I18n fallback
    $options = array();
    $criteria = QubitCultureFallback::addFallbackCriteria($criteria, 'QubitTerm', $options);

    $this->terms = QubitTerm::get($criteria);

    //determine if user has edit priviliges
    $this->editCredentials = false;
    if (SecurityPriviliges::editCredentials($this->getUser(), 'actor'))
    {
      $this->editCredentials = true;
    }

    //set view template
    switch ($this->getRequestParameter('template'))
    {
      case 'anotherTemplate' :
        $this->setTemplate('anotherTemplate');
        break;
      default :
        //$this->setTemplate(sfConfig::get('app_default_template_mediatype_list'));
        $this->setTemplate('list');
    }
  }
}
